Trait FixedOptionalSerde

pub trait FixedOptionalSerde: Sealed { }
This trait is used to provide supertraits to the Fixed trait depending on the crate’s optional features, and should not be used directly.

If the serde feature is enabled and the serde-str feature is disabled, [Serialize] and [Deserialize] are supertraits of Fixed.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors